//===========================================================================
//=
//=  Copyright (C) 2008 Maxim Integrated Products
//=  All rights Reserved. Printed in U.S.A.
//=
//=  Permission is hereby granted, free of charge, to any person obtaining a
//=  copy of this software and associated documentation files (the 
//=  "Software"), to deal in the Software without restriction, including
//=  without limitation the rights to use, copy, modify, merge, publish,
//=  distribute, sublicense, and/or sell copies of the Software, and to
//=  permit persons to whom the Software is furnished to do so, subject to
//=  the following conditions:
//=  
//=  The above copyright notice and this permission notice shall be included
//=  in all copies or substantial portions of the Software source code.
//=  
//=  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//=  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
//=  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
//=  IN NO EVENT SHALL MAXIM INTEGRATED PRODUCTS BE LIABLE FOR ANY CLAIM, 
//=  DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
//=  OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR 
//=  THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//=
//=  Except as contained in this notice, the name of Maxim Integrated Products
//=  shall not be used except as stated in the Maxim Branding Policy.
//=
//=     Description: MAXQ2000 uIP Ethernet Example Application
//=                 
//=        Filename: cprintf.c
//=
//=        Compiler: Rowley CrossWorks C compiler
//=
//=        Hardware: MAXQ2000 Evaluation Kit (Rev B)
//=
//===========================================================================

#include <stdio.h>
#include <stdarg.h>

#include "copybuf.h"
#include "cprintf.h"

/* Buffer used by the cprintf() macro for strings stored in code space */
static unsigned char cbuf[80];

/* Calls the printf() function after copying code-space string to RAM buffer
 *
 * Comments:
 *
 *   As the MAXQ2000 has limited RAM, copying all of the static string data
 *    into RAM reduces the space for the Rowley soft stack. We, therefore, 
 *    copy only the string needed at the current instant into a single buffer
 *    and pass this buffer to vprintf() along with the variable argument list.
 * 
 * Input arguments:
 *  
 *   format - code-space formatting string
 *   [<arg1> .. <argn>] - additional parameters to printf(str, ...)
 *
 * Returns:
 *
 *   result code from vprintf
 *
 */
int cprintf(const __code char *format, ...)
{
  va_list ap;

  /* Initialize the varaiable argument list pointer */
  va_start(ap, format);

  /* Copy the code space string to RAM */
  asm_copybuffer(cbuf, format, 80);

  /* Call vprintf with our RAM format string plus the varaible argument list */
  return vprintf((char *)cbuf, ap);
}
