//===========================================================================
//=
//=  Copyright (C) 2008 Maxim Integrated Products
//=  All rights Reserved. Printed in U.S.A.
//=
//=  Permission is hereby granted, free of charge, to any person obtaining a
//=  copy of this software and associated documentation files (the 
//=  "Software"), to deal in the Software without restriction, including
//=  without limitation the rights to use, copy, modify, merge, publish,
//=  distribute, sublicense, and/or sell copies of the Software, and to
//=  permit persons to whom the Software is furnished to do so, subject to
//=  the following conditions:
//=  
//=  The above copyright notice and this permission notice shall be included
//=  in all copies or substantial portions of the Software source code.
//=  
//=  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//=  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
//=  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
//=  IN NO EVENT SHALL MAXIM INTEGRATED PRODUCTS BE LIABLE FOR ANY CLAIM, 
//=  DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
//=  OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR 
//=  THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//=
//=  Except as contained in this notice, the name of Maxim Integrated Products
//=  shall not be used except as stated in the Maxim Branding Policy.
//=
//=     Description: MAXQ2000 uIP Ethernet Example Application
//=                 
//=        Filename: serialio.c
//=
//=        Compiler: Rowley CrossWorks C compiler
//=
//=        Hardware: MAXQ2000 Evaluation Kit (Rev B)
//=
//===========================================================================

#include <maxq2000.h>

#include "serialio.h"

/*
 * Initialize serial functions for the MAXQ2000 ART board. 
 * 20MHz oscillator is assumed when calculating the value for PR0
 *
 * Input arguments:
 *
 *   <none>
 *
 * Returns:
 *
 *   <none>
 *
 */
void serialio_init(unsigned int phasereg)
{
  /* Set up the serial port for 115200 bps, no parity, 8 bits, 1 stop bit */
  SCON0 = SCON0_REN | SCON0_SM1;
  SMD0 = SMD0_SMOD0;   
  PR0 = phasereg;            
  PD7 = 0x01;              /* P7.0 output, P7.1 input */
  PO7 = 0x01;              /* P7.0 idle high, P7.1 no weak pullup */
}

/* Hook function for Rowley printf() routines to send serial character 
 *
 * Input arguments:      
 *
 *   x - character to send to console held in lower byte
 *
 * Returns:
 *
 *   <none>
 *
 */
int __putchar(int ch)
{
  SBUF0 = ch;
  while (!(SCON0 & 0x02));
  SCON0 &= ~0x02;

  return ch;
}

/* Waits for, and reads, a character over the serial port
 *
 * Input arguments:      
 *
 *   <none>
 *
 * Returns:
 *
 *   character received over serial port
 *
 */
uint8_t serialio_read(void)
{
  while(!(SCON0 & 1)); /* Wait for RI to go high */
  SCON0 &= ~0x01; /* Clear it */
  return (uint8_t)SBUF0; /* Pass back the receive buffer */
}


/* Query character ready
 *
 * Input arguments:      
 *
 *   <none>
 *
 * Returns:
 *
 *   1 if character in UART buffer, 0 otherwise
 *
 */
uint8_t serialio_isready(void)
{
  if (SCON0 & 1) {
    return 1;
  } else {
    return 0;
  }
}
