//===========================================================================
//=
//=  Copyright (C) 2008 Maxim Integrated Products
//=  All rights Reserved. Printed in U.S.A.
//=
//=  Permission is hereby granted, free of charge, to any person obtaining a
//=  copy of this software and associated documentation files (the 
//=  "Software"), to deal in the Software without restriction, including
//=  without limitation the rights to use, copy, modify, merge, publish,
//=  distribute, sublicense, and/or sell copies of the Software, and to
//=  permit persons to whom the Software is furnished to do so, subject to
//=  the following conditions:
//=  
//=  The above copyright notice and this permission notice shall be included
//=  in all copies or substantial portions of the Software source code.
//=  
//=  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//=  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
//=  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
//=  IN NO EVENT SHALL MAXIM INTEGRATED PRODUCTS BE LIABLE FOR ANY CLAIM, 
//=  DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
//=  OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR 
//=  THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//=
//=  Except as contained in this notice, the name of Maxim Integrated Products
//=  shall not be used except as stated in the Maxim Branding Policy.
//=
//=     Description: MAXQ2000 uIP Ethernet Example Application
//=                 
//=        Filename: spi.c
//=
//=        Compiler: Rowley CrossWorks C compiler
//=
//=        Hardware: MAXQ2000 Evaluation Kit (Rev B)
//=
//===========================================================================

#include <maxq2000.h>

#include "spi.h"

void spi_init(void)
{
  /* Set up the SPI port */
  SPICF = 0x00;       /* Rising clock latches data, 8-bit */
  SPICK = 0x00;       /* div 2 sysclock == 10MHz; ENC28J60 rated for 26MHz */
  SPICN |= 0x03;      /* Enable SPI master */
  PD5 |= 0x10;        /* /SS used as an output */
  PO5 |= 0x10;        /* /SS = 1 */
}

void spi_ss(unsigned char x)
{
  if (x > 0) {
    PO5 |= 0x10;
  } else {
    PO5 &= 0xef;
  }
}

/* 
 * Transmit a character over SPI. Also reads back character clocked in
 *
 * Input arguments:      
 *
 *   in - character to transmit out of SPI MOSI pin
 *
 * Returns:
 *
 *   character received via SPI MISO pin
 *
 */
uint8_t spi_txrx(uint8_t in)
{
  uint8_t out;
  /* Caveat utilitor! This may hang on SPICN.6 and SPICN.7 forever */

  while(SPICN & 0x80);           /* Wait for BUSY to be low */
  SPICN &= ~0x40;                /* Clear transfer complete */
  SPIB = in;                     /* Start the transfer */
  while(!(SPICN & 0x40));        /* Wait for Transfer Complete */
  out = SPIB;                    /* Copy off what was sent in */
  SPICN &= ~0x40;                /* Clear transfer complete */

  return out;
}
